@@ -10,9 +10,10 @@ class GoogleAIEmbedderConfig(BaseEmbedderConfig):
         self,
         model: Optional[str] = None,
         deployment_name: Optional[str] = None,
+        vector_dimension: Optional[int] = None,
         task_type: Optional[str] = None,
         title: Optional[str] = None,
     ):
-        super().__init__(model, deployment_name)
+        super().__init__(model, deployment_name, vector_dimension)
         self.task_type = task_type or "retrieval_document"
         self.title = title or "Embeddings for Embedchain"
