@@ -9,10 +9,11 @@ class GPT4AllEmbedder(BaseEmbedder):
     def __init__(self, config: Optional[BaseEmbedderConfig] = None):
         super().__init__(config=config)
 
-        from langchain.embeddings import \
-            GPT4AllEmbeddings as LangchainGPT4AllEmbeddings
+        from langchain_community.embeddings import GPT4AllEmbeddings as LangchainGPT4AllEmbeddings
 
-        embeddings = LangchainGPT4AllEmbeddings()
+        model_name = self.config.model or "all-MiniLM-L6-v2-f16.gguf"
+        gpt4all_kwargs = {'allow_download': 'True'}
+        embeddings = LangchainGPT4AllEmbeddings(model_name=model_name, gpt4all_kwargs=gpt4all_kwargs)
         embedding_fn = BaseEmbedder._langchain_default_concept(embeddings)
         self.set_embedding_fn(embedding_fn=embedding_fn)
 
