@@ -1,32 +1,29 @@
-import importlib
 import logging
 import os
 from collections.abc import Generator
 from typing import Any, Optional, Union
 
-import google.generativeai as genai
+try:
+    import google.generativeai as genai
+except ImportError:
+    raise ImportError("GoogleLlm requires extra dependencies. Install with `pip install google-generativeai`") from None
 
 from embedchain.config import BaseLlmConfig
 from embedchain.helpers.json_serializable import register_deserializable
 from embedchain.llm.base import BaseLlm
 
+logger = logging.getLogger(__name__)
+
 
 @register_deserializable
 class GoogleLlm(BaseLlm):
     def __init__(self, config: Optional[BaseLlmConfig] = None):
-        if "GOOGLE_API_KEY" not in os.environ:
-            raise ValueError("Please set the GOOGLE_API_KEY environment variable.")
-
-        try:
-            importlib.import_module("google.generativeai")
-        except ModuleNotFoundError:
-            raise ModuleNotFoundError(
-                "The required dependencies for GoogleLlm are not installed."
-                'Please install with `pip install --upgrade "embedchain[google]"`'
-            ) from None
-
         super().__init__(config)
-        genai.configure(api_key=os.environ["GOOGLE_API_KEY"])
+        if not self.config.api_key and "GOOGLE_API_KEY" not in os.environ:
+            raise ValueError("Please set the GOOGLE_API_KEY environment variable or pass it in the config.")
+
+        api_key = self.config.api_key or os.getenv("GOOGLE_API_KEY")
+        genai.configure(api_key=api_key)
 
     def get_llm_model_answer(self, prompt):
         if self.config.system_prompt:
@@ -36,7 +33,7 @@ class GoogleLlm(BaseLlm):
 
     def _get_answer(self, prompt: str) -> Union[str, Generator[Any, Any, None]]:
         model_name = self.config.model or "gemini-pro"
-        logging.info(f"Using Google LLM model: {model_name}")
+        logger.info(f"Using Google LLM model: {model_name}")
         model = genai.GenerativeModel(model_name=model_name)
 
         generation_config_params = {
