@@ -5,7 +5,7 @@ class BaseLoader(JSONSerializable):
     def __init__(self):
         pass
 
-    def load_data():
+    def load_data(self, url):
         """
         Implemented by child classes
         """
