@@ -9,7 +9,14 @@ except ImportError:
     ) from None
 
 from langchain_community.document_loaders import GoogleDriveLoader as Loader
-from langchain_community.document_loaders import UnstructuredFileIOLoader
+
+try:
+    import unstructured  # noqa: F401
+    from langchain_community.document_loaders import UnstructuredFileIOLoader
+except ImportError:
+    raise ImportError(
+        'Unstructured file requires extra dependencies. Install with `pip install "unstructured[local-inference, all-docs]"`'  # noqa: E501
+    ) from None
 
 from embedchain.helpers.json_serializable import register_deserializable
 from embedchain.loaders.base_loader import BaseLoader
