@@ -11,6 +11,8 @@ from embedchain.utils.misc import clean_string
 
 SLACK_API_BASE_URL = "https://www.slack.com/api/"
 
+logger = logging.getLogger(__name__)
+
 
 class SlackLoader(BaseLoader):
     def __init__(self, config: Optional[dict[str, Any]] = None):
@@ -38,7 +40,7 @@ class SlackLoader(BaseLoader):
                 "SLACK_USER_TOKEN environment variables not provided. Check `https://docs.embedchain.ai/data-sources/slack` to learn more."  # noqa:E501
             )
 
-        logging.info(f"Creating Slack Loader with config: {config}")
+        logger.info(f"Creating Slack Loader with config: {config}")
         # get slack client config params
         slack_bot_token = os.getenv("SLACK_USER_TOKEN")
         ssl_cert = ssl.create_default_context(cafile=certifi.where())
@@ -54,7 +56,7 @@ class SlackLoader(BaseLoader):
             headers=headers,
             team_id=team_id,
         )
-        logging.info("Slack Loader setup successful!")
+        logger.info("Slack Loader setup successful!")
 
     @staticmethod
     def _check_query(query):
@@ -69,7 +71,7 @@ class SlackLoader(BaseLoader):
             data = []
             data_content = []
 
-            logging.info(f"Searching slack conversations for query: {query}")
+            logger.info(f"Searching slack conversations for query: {query}")
             results = self.client.search_messages(
                 query=query,
                 sort="timestamp",
@@ -79,7 +81,7 @@ class SlackLoader(BaseLoader):
 
             messages = results.get("messages")
             num_message = len(messages)
-            logging.info(f"Found {num_message} messages for query: {query}")
+            logger.info(f"Found {num_message} messages for query: {query}")
 
             matches = messages.get("matches", [])
             for message in matches:
@@ -88,16 +90,16 @@ class SlackLoader(BaseLoader):
                 content = clean_string(text)
 
                 message_meta_data_keys = ["iid", "team", "ts", "type", "user", "username"]
-                meta_data = {}
+                metadata = {}
                 for key in message.keys():
                     if key in message_meta_data_keys:
-                        meta_data[key] = message.get(key)
-                meta_data.update({"url": url})
+                        metadata[key] = message.get(key)
+                metadata.update({"url": url})
 
                 data.append(
                     {
                         "content": content,
-                        "meta_data": meta_data,
+                        "meta_data": metadata,
                     }
                 )
                 data_content.append(content)
@@ -107,7 +109,7 @@ class SlackLoader(BaseLoader):
                 "data": data,
             }
         except Exception as e:
-            logging.warning(f"Error in loading slack data: {e}")
+            logger.warning(f"Error in loading slack data: {e}")
             raise ValueError(
                 f"Error in loading slack data: {e}. Check `https://docs.embedchain.ai/data-sources/slack` to learn more."  # noqa:E501
             ) from e
